Rust Steam Deck gamepad raw input
This project is unofficial! This project is not affiliated with Valve Corporation.
This uses hidraw to access inputs, which bypasses any input remapping that might be performed by Steam. This allows access to all inputs, all in a single packet, without having to integrate with any Steam APIs or to even have Steam open at all. This is also not subject to limitations of Xbox-style gamepads, meaning that all analog axes can be accessed independently.
This code can be compiled for any platform, but finding the device node will always fail on not-Linux.
Modules
Structs
- Input
Report - Struct representing the data from the controller
Constants
- INPUT_
REPORT_ MAGIC - Magic number at the beginning of every packet
Functions
- find_
deck_ hidraw - Find the hidraw device for the Deck’s controls